<div align="center">
  <img src="res/logo.png" alt="pymocd logo" width="50%">  
  
  **Python Multi-Objective High-performance Evolutionary Algorithms for Community Detection**  
  
![GitHub Actions Workflow Status](https://img.shields.io/github/actions/workflow/status/oliveira-sh/pymocd/rust.yml)
![PyPI - Version](https://img.shields.io/pypi/v/pymocd)
![PyPI - License](https://img.shields.io/pypi/l/pymocd)


</div>

## Overview  
**pymocd** is a Rust-powered Python library designed for efficient multi-objective evolutionary algorithms in community detection. It enhances performance over traditional methods, making it ideal for large-scale graph analysis. This project continues from [re-mocd](https://github.com/0l1ve1r4/re-mocd).  

## Features  
- High-performance Rust backend for computational efficiency  
- Multi-objective optimization for better community structures  
- Scalable to large graphs  
- Easy-to-use Python API  

## Installation and Usage

Visit the [documentation](#) (TODO) for detailed instructions and examples.

## Contributing  

Contributions are welcome! If you have ideas for improvements, feel free to submit issues or pull, this project is licensed under the **GPL-3.0 or later**.  

<p align="left">
  <a href="https://github.com/0l1ve1r4">
    <img src="https://avatars.githubusercontent.com/u/82629748?v=4" width="50" height="50" style="border-radius: 50%;">
  </a>
  <a href="https://github.com/ol1veir4s">
    <img src="https://avatars.githubusercontent.com/u/202351572?v=4" width="50" height="50" style="border-radius: 50%;">
  </a>
  <a href="https://github.com/matt-cornell">
    <img src="https://avatars.githubusercontent.com/u/107312119?v=4" width="50" height="50" style="border-radius: 50%;">
  </a>
</p>
